Promise.resolve().then(function () {
  return babelHelpers.interopRequireWildcard(require('my-module'));
});
Promise.resolve().then(function () {
  return babelHelpers.interopRequireWildcard(require('my-module'));
});
