Promise.resolve().then(() => babelHelpers.interopRequireWildcard(require(`1`)));

Promise.resolve(`${tag`2`}`).then(s => babelHelpers.interopRequireWildcard(require(s)));

Promise.resolve(`3-${MODULE}`).then(s => babelHelpers.interopRequireWildcard(require(s)));
