Promise.resolve("".concat({
  'answer': 42
})).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(['foo', 'bar'])).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(42)).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(void 0)).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(undefined)).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(null)).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(true)).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
Promise.resolve("".concat(Symbol())).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
