var _templateObject = babelHelpers.taggedTemplateLiteral(["2"], ["2"]);

Promise.resolve().then(function () {
  return babelHelpers.interopRequireWildcard(require("1"));
});

Promise.resolve("" + String(tag(_templateObject))).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});

Promise.resolve("3-" + String(MODULE)).then(function (s) {
  return babelHelpers.interopRequireWildcard(require(s));
});
